
from django.db import models
from wagtail.fields import StreamField
from wagtail.blocks import *
from wagtail.images.blocks import ImageChooserBlock
from django.core.validators import MaxValueValidator, MinValueValidator 
from .common import *
from wagtail_color_panel.fields import ColorField

class AbstractCarousel(models.Model):
    bannerHeight = models.PositiveIntegerField(default=300,validators=[MinValueValidator(50), MaxValueValidator(2000)],verbose_name="Height")
    bannerWidth = models.PositiveIntegerField(default=1400, validators=[MinValueValidator(150), MaxValueValidator(2560)],verbose_name="Width")
    bannerTimer = models.PositiveIntegerField(default=3000,verbose_name="Slide Time in ms")
    bannercontent = StreamField(
        [
            ('slide', StructBlock([
                ("image", ImageChooserBlock(required=True)),
                ("title", CharBlock(required=False)),
                ("link", URLBlock(required=False,label="External Link")),
                ("page", PageChooserBlock(required=False,label="Internal Link")),
            ]))
        ],blank=True,null=True,use_json_field=True,verbose_name="Content"
    )
    class Meta:
        abstract=True

class AbstractHero(models.Model):
    hero=StreamField([
        ('Slide',StreamBlock([
            ('row',StreamBlock([
                ('tile',StructBlock([
                    ('bg',NativeColorBlock(default="#FFFFFF",required=False,label="BG (Opacity)")),
                    ("bgGradient", CharBlock(required=False)),
                    ('fg',NativeColorBlock(default="#000000",required=False)),
                    ('image',ImageChooserBlock(required=False)),
                    ('page',PageChooserBlock(required=False)),
                    ("title", CharBlock(required=False)),
                    ('size',ChoiceBlock(choices=Heading_SIZE_LIST, required=False,default="text-['1.5rem'] md:text-['2.125rem'] lg:text-['2.125rem']",label="Title Size"))
                    
                ]))
                
            ]))
        ]))
    ],blank=True, null=True, use_json_field=True)
    class Meta:
        abstract=True






class AbstractCustomColor(models.Model):
    bgColor = ColorField(
        default="#FFFFFF", verbose_name="BG", blank=True, null=True)
    fgColor = ColorField(
        default="#000000", verbose_name="FG", blank=True, null=True)

    hoverBgColor = ColorField(
        default="#FFFFFF", verbose_name="Hover BG", blank=True, null=True)
    hoverFgColor = ColorField(
        default="#000000", verbose_name="Hover FG", blank=True, null=True)
    
    activeBgColor = ColorField(
        default="#FFFFFF", verbose_name="Active BG", blank=True, null=True)
    activeFgColor = ColorField(
        default="#000000", verbose_name="Active FG", blank=True, null=True)
    class Meta:
        abstract=True